@@ -6,7 +6,7 @@ BEGIN {
   $BenchmarkAnything::Storage::Frontend::Lib::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Basic functions to access a BenchmarkAnything store
-$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.010';
+$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.011';
 use Scalar::Util 'reftype';
 
 
@@ -266,7 +266,7 @@ sub createdb
                 no warnings 'once'; # avoid 'Name "DBI::errstr" used only once'
 
                 require DBI;
-                require File::Slurp;
+                require File::Slurper;
                 require File::ShareDir;
                 use DBIx::MultiStatementDo;
 
@@ -278,7 +278,7 @@ sub createdb
                  or die "benchmarkanything: can not parse DBI DSN '$dsn'";
                 my ($dbname) = $driver_dsn =~ m/database=(\w+)/g;
                 my $sql_file = File::ShareDir::dist_file('BenchmarkAnything-Storage-Backend-SQL', "create-schema.$driver");
-                my $sql      = File::Slurp::read_file($sql_file);
+                my $sql      = File::Slurper::read_text($sql_file);
                 $sql         =~ s/^use `testrundb`;/use `$dbname`;/m if $dbname; # replace BenchmarkAnything::Storage::Backend::SQL's default
 
                 # execute schema SQL
@@ -301,7 +301,7 @@ sub init_workdir
         require File::Basename;
         require File::ShareDir;
         require File::HomeDir;
-        require File::Slurp;
+        require File::Slurper;
 
         my $home_ba = File::HomeDir->my_home."/.benchmarkanything";
         my $command = File::Basename::basename($0);
@@ -323,7 +323,7 @@ sub init_workdir
 
                 if (! -e $dest_file)
                 {
-                        my $content     =  File::Slurp::read_file($source_file);
+                        my $content     =  File::Slurper::read_text($source_file);
 
                         # poor man's templating
                         $content        =~ s{\[%\s*CLIENTCFG\s*%\]}{$home_ba/client.cfg}g;
